==> aws-cdk.aws-codestar-1.139.0.tar.gz: package/.warnings.jsii.js <==
function _aws_cdk_aws_codestar_RepositoryVisibility(p) {
}
function _aws_cdk_aws_codestar_IGitHubRepository(p) {
}
function _aws_cdk_aws_codestar_CfnGitHubRepositoryProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.code))
        _aws_cdk_aws_codestar_CfnGitHubRepository_CodeProperty(p.code);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_codestar_GitHubRepositoryProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.visibility))
        _aws_cdk_aws_codestar_RepositoryVisibility(p.visibility);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_codestar_GitHubRepository(p) {
}
function _aws_cdk_aws_codestar_CfnGitHubRepository(p) {
}
function _aws_cdk_aws_codestar_CfnGitHubRepository_S3Property(p) {
}
function _aws_cdk_aws_codestar_CfnGitHubRepository_CodeProperty(p) {
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
const visitedObjects = new Set();
class DeprecationError extends Error {
}
module.exports = { print, _aws_cdk_aws_codestar_RepositoryVisibility, _aws_cdk_aws_codestar_IGitHubRepository, _aws_cdk_aws_codestar_CfnGitHubRepositoryProps, _aws_cdk_aws_codestar_GitHubRepositoryProps, _aws_cdk_aws_codestar_GitHubRepository, _aws_cdk_aws_codestar_CfnGitHubRepository, _aws_cdk_aws_codestar_CfnGitHubRepository_S3Property, _aws_cdk_aws_codestar_CfnGitHubRepository_CodeProperty };
module.exports.DeprecationError = DeprecationError;

==> aws-cdk.aws-codestar-1.140.0.tar.gz: package/.warnings.jsii.js <==
function _aws_cdk_aws_codestar_RepositoryVisibility(p) {
}
function _aws_cdk_aws_codestar_IGitHubRepository(p) {
}
function _aws_cdk_aws_codestar_CfnGitHubRepositoryProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.code))
        _aws_cdk_aws_codestar_CfnGitHubRepository_CodeProperty(p.code);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_codestar_GitHubRepository(p) {
}
function _aws_cdk_aws_codestar_GitHubRepositoryProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.visibility))
        _aws_cdk_aws_codestar_RepositoryVisibility(p.visibility);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_codestar_CfnGitHubRepository(p) {
}
function _aws_cdk_aws_codestar_CfnGitHubRepository_S3Property(p) {
}
function _aws_cdk_aws_codestar_CfnGitHubRepository_CodeProperty(p) {
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
const visitedObjects = new Set();
class DeprecationError extends Error {
}
module.exports = { print, _aws_cdk_aws_codestar_RepositoryVisibility, _aws_cdk_aws_codestar_IGitHubRepository, _aws_cdk_aws_codestar_CfnGitHubRepositoryProps, _aws_cdk_aws_codestar_GitHubRepository, _aws_cdk_aws_codestar_GitHubRepositoryProps, _aws_cdk_aws_codestar_CfnGitHubRepository, _aws_cdk_aws_codestar_CfnGitHubRepository_S3Property, _aws_cdk_aws_codestar_CfnGitHubRepository_CodeProperty };
module.exports.DeprecationError = DeprecationError;
